==> pygubu_0.35.5.orig.tar.gz: pygubu-0.35.5/src/pygubu/theming/bootstrap/themes.py <==
STANDARD_THEMES = {
    "pbs_cosmo": {
        "type": "light",
        "colors": {
            "primary": "#2780e3",
            "secondary": "#7E8081",
            "success": "#3fb618",
            "info": "#9954bb",
            "warning": "#ff7518",
            "danger": "#ff0039",
            "light": "#F8F9FA",
            "dark": "#373A3C",
            "bg": "#ffffff",
            "fg": "#373a3c",
            "selectbg": "#7e8081",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#373a3c",
            "inputbg": "#fdfdfe",
            "active": "#efefef",
        },
    },
    "pbs_flatly": {
        "type": "light",
        "colors": {
            "primary": "#2c3e50",
            "secondary": "#95a5a6",
            "success": "#18bc9c",
            "info": "#3498db",
            "warning": "#f39c12",
            "danger": "#e74c3c",
            "light": "#ECF0F1",
            "dark": "#7B8A8B",
            "bg": "#ffffff",
            "fg": "#212529",
            "selectbg": "#95a5a6",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#212529",
            "inputbg": "#ffffff",
            "active": "#e2e2e2",
        },
    },
    "pbs_litera": {
        "type": "light",
        "colors": {
            "primary": "#4582ec",
            "secondary": "#adb5bd",
            "success": "#02b875",
            "info": "#17a2b8",
            "warning": "#f0ad4e",
            "danger": "#d9534f",
            "light": "#F8F9FA",
            "dark": "#343A40",
            "bg": "#ffffff",
            "fg": "#343a40",
            "selectbg": "#adb5bd",
            "selectfg": "#ffffff",
            "border": "#bfbfbf",
            "inputfg": "#343a40",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_minty": {
        "type": "light",
        "colors": {
            "primary": "#78c2ad",
            "secondary": "#f3969a",
            "success": "#56cc9d",
            "info": "#6cc3d5",
            "warning": "#ffce67",
            "danger": "#ff7851",
            "light": "#F8F9FA",
            "dark": "#343A40",
            "bg": "#ffffff",
            "fg": "#5a5a5a",
            "selectbg": "#f3969a",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#696969",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_lumen": {
        "type": "light",
        "colors": {
            "primary": "#158cba",
            "secondary": "#919191",
            "success": "#28b62c",
            "info": "#75caeb",
            "warning": "#ff851b",
            "danger": "#ff4136",
            "light": "#F6F6F6",
            "dark": "#555555",
            "bg": "#ffffff",
            "fg": "#555555",
            "selectbg": "#919191",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#555555",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_sandstone": {
        "type": "light",
        "colors": {
            "primary": "#325D88",
            "secondary": "#8e8c84",
            "success": "#93c54b",
            "info": "#29abe0",
            "warning": "#f47c3c",
            "danger": "#d9534f",
            "light": "#F8F5F0",
            "dark": "#3E3F3A",
            "bg": "#ffffff",
            "fg": "#3e3f3a",
            "selectbg": "#8e8c84",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#6E6D69",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_yeti": {
        "type": "light",
        "colors": {
            "primary": "#008cba",
            "secondary": "#707070",
            "success": "#43ac6a",
            "info": "#5bc0de",
            "warning": "#e99002",
            "danger": "#f04124",
            "light": "#EEEEEE",
            "dark": "#222222",
            "bg": "#ffffff",
            "fg": "#222222",
            "selectbg": "#707070",
            "selectfg": "#ffffff",
            "border": "#cccccc",
            "inputfg": "#222222",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_pulse": {
        "type": "light",
        "colors": {
            "primary": "#593196",
            "secondary": "#69676E",
            "success": "#13b955",
            "info": "#009cdc",
            "warning": "#efa31d",
            "danger": "#fc3939",
            "light": "#F9F8FC",
            "dark": "#17141F",
            "bg": "#ffffff",
            "fg": "#444444",
            "selectbg": "#69676e",
            "selectfg": "#ffffff",
            "border": "#cbc8d0",
            "inputfg": "#444444",
            "inputbg": "#fdfdfe",
            "active": "#e5e5e5",
        },
    },
    "pbs_united": {
        "type": "light",
        "colors": {
            "primary": "#e95420",
            "secondary": "#aea79f",
            "success": "#38b44a",
            "info": "#17a2b8",
            "warning": "#efb73e",
            "danger": "#df382c",
            "light": "#E9ECEF",
            "dark": "#772953",
            "bg": "#ffffff",
            "fg": "#333333",
            "selectbg": "#aea79f",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#333333",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_morph": {
        "type": "light",
        "colors": {
            "primary": "#378DFC",
            "secondary": "#aaaaaa",
            "success": "#43cc29",
            "info": "#5B62F4",
            "warning": "#FFC107",
            "danger": "#E52527",
            "light": "#F0F5FA",
            "dark": "#212529",
            "bg": "#D9E3F1",
            "fg": "#7B8AB8",
            "selectbg": "#aaaaaa",
            "selectfg": "#FBFDFF",
            "border": "#B9C7DA",
            "inputfg": "#7F8EBA",
            "inputbg": "#F0F5FA",
            "active": "#C3CCD8",
        },
    },
    "pbs_journal": {
        "type": "light",
        "colors": {
            "primary": "#eb6864",
            "secondary": "#aaaaaa",
            "success": "#22b24c",
            "info": "#336699",
            "warning": "#f5e625",
            "danger": "#f57a00",
            "light": "#F8F9FA",
            "dark": "#222222",
            "bg": "#ffffff",
            "fg": "#222222",
            "selectbg": "#aaaaaa",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#565656",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_darkly": {
        "type": "dark",
        "colors": {
            "primary": "#375a7f",
            "secondary": "#444444",
            "success": "#00bc8c",
            "info": "#3498db",
            "warning": "#f39c12",
            "danger": "#e74c3c",
            "light": "#ADB5BD",
            "dark": "#303030",
            "bg": "#222222",
            "fg": "#ffffff",
            "selectbg": "#555555",
            "selectfg": "#ffffff",
            "border": "#222222",
            "inputfg": "#ffffff",
            "inputbg": "#2f2f2f",
            "active": "#1F1F1F",
        },
    },
    "pbs_superhero": {
        "type": "dark",
        "colors": {
            "primary": "#4c9be8",
            "secondary": "#4e5d6c",
            "success": "#5cb85c",
            "info": "#5bc0de",
            "warning": "#f0ad4e",
            "danger": "#d9534f",
            "light": "#ABB6C2",
            "dark": "#20374C",
            "bg": "#2b3e50",
            "fg": "#ffffff",
            "selectbg": "#526170",
            "selectfg": "#ffffff",
            "border": "#222222",
            "inputfg": "#ebebeb",
            "inputbg": "#32465a",
            "active": "#2B4155",
        },
    },
    "pbs_solar": {
        "type": "dark",
        "colors": {
            "primary": "#bc951a",
            "secondary": "#94a2a4",
            "success": "#44aca4",
            "info": "#3f98d7",
            "warning": "#d05e2f",
            "danger": "#d95092",
            "light": "#A9BDBD",
            "dark": "#073642",
            "bg": "#002B36",
            "fg": "#ffffff",
            "selectbg": "#0b5162",
            "selectfg": "#ffffff",
            "border": "#00252e",
            "inputfg": "#A9BDBD",
            "inputbg": "#073642",
            "active": "#002730",
        },
    },
    "pbs_cyborg": {
        "type": "dark",
        "colors": {
            "primary": "#2a9fd6",
            "secondary": "#555555",
            "success": "#77b300",
            "info": "#9933cc",
            "warning": "#ff8800",
            "danger": "#cc0000",
            "light": "#ADAFAE",
            "dark": "#222222",
            "bg": "#060606",
            "fg": "#ffffff",
            "selectbg": "#454545",
            "selectfg": "#ffffff",
            "border": "#060606",
            "inputfg": "#ffffff",
            "inputbg": "#191919",
            "active": "#282828",
        },
    },
    "pbs_vapor": {
        "type": "dark",
        "colors": {
            "primary": "#6e40c0",
            "secondary": "#ea38b8",
            "success": "#3af180",
            "info": "#1da2f2",
            "warning": "#ffbd05",
            "danger": "#e34b54",
            "light": "#44d7e8",
            "dark": "#170229",
            "bg": "#190831",
            "fg": "#32fbe2",
            "selectbg": "#461a8a",
            "selectfg": "#ffffff",
            "border": "#060606",
            "inputfg": "#bfb6cd",
            "inputbg": "#30115e",
            "active": "#17082E",
        },
    },
    "pbs_simplex": {
        "type": "light",
        "colors": {
            "primary": "#d8220e",
            "secondary": "#858e96",
            "success": "#469307",
            "info": "#0099ce",
            "warning": "#d88220",
            "danger": "#9a479e",
            "light": "#f2f2f2",
            "dark": "#3b3d3f",
            "bg": "#fcfcfc",
            "fg": "#3b3d3f",
            "selectbg": "#a9afb6",
            "selectfg": "#ffffff",
            "border": "#858e96",
            "inputfg": "#3b3d3f",
            "inputbg": "#fcfcfc",
            "active": "#e2e2e2",
        },
    },
    "pbs_cerculean": {
        "type": "light",
        "colors": {
            "primary": "#4bb1ea",
            "secondary": "#a9b4be",
            "success": "#84b251",
            "info": "#225384",
            "warning": "#e16e25",
            "danger": "#cf3c40",
            "light": "#eceef1",
            "dark": "#33383e",
            "bg": "#ffffff",
            "fg": "#2ea4e7",
            "selectbg": "#adb5bd",
            "selectfg": "#ffffff",
            "border": "#a9b4be",
            "inputfg": "#495057",
            "inputbg": "#ffffff",
            "active": "#e5e5e5",
        },
    },
}

==> pygubu_0.37.orig.tar.gz: pygubu-0.37/src/pygubu/theming/bootstrap/themes.py <==
STANDARD_THEMES = {
    "pbs_cosmo": {
        "type": "light",
        "colors": {
            "primary": "#2780e3",
            "secondary": "#7E8081",
            "success": "#3fb618",
            "info": "#9954bb",
            "warning": "#ff7518",
            "danger": "#ff0039",
            "light": "#F8F9FA",
            "dark": "#373A3C",
            "bg": "#ffffff",
            "fg": "#373a3c",
            "selectbg": "#7e8081",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#373a3c",
            "inputbg": "#fdfdfe",
            "active": "#efefef",
        },
    },
    "pbs_flatly": {
        "type": "light",
        "colors": {
            "primary": "#2c3e50",
            "secondary": "#95a5a6",
            "success": "#18bc9c",
            "info": "#3498db",
            "warning": "#f39c12",
            "danger": "#e74c3c",
            "light": "#ECF0F1",
            "dark": "#7B8A8B",
            "bg": "#ffffff",
            "fg": "#212529",
            "selectbg": "#95a5a6",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#212529",
            "inputbg": "#ffffff",
            "active": "#e2e2e2",
        },
    },
    "pbs_litera": {
        "type": "light",
        "colors": {
            "primary": "#4582ec",
            "secondary": "#adb5bd",
            "success": "#02b875",
            "info": "#17a2b8",
            "warning": "#f0ad4e",
            "danger": "#d9534f",
            "light": "#F8F9FA",
            "dark": "#343A40",
            "bg": "#ffffff",
            "fg": "#343a40",
            "selectbg": "#adb5bd",
            "selectfg": "#ffffff",
            "border": "#bfbfbf",
            "inputfg": "#343a40",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_minty": {
        "type": "light",
        "colors": {
            "primary": "#78c2ad",
            "secondary": "#f3969a",
            "success": "#56cc9d",
            "info": "#6cc3d5",
            "warning": "#ffce67",
            "danger": "#ff7851",
            "light": "#F8F9FA",
            "dark": "#343A40",
            "bg": "#ffffff",
            "fg": "#5a5a5a",
            "selectbg": "#f3969a",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#696969",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_lumen": {
        "type": "light",
        "colors": {
            "primary": "#158cba",
            "secondary": "#919191",
            "success": "#28b62c",
            "info": "#75caeb",
            "warning": "#ff851b",
            "danger": "#ff4136",
            "light": "#F6F6F6",
            "dark": "#555555",
            "bg": "#ffffff",
            "fg": "#555555",
            "selectbg": "#919191",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#555555",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_sandstone": {
        "type": "light",
        "colors": {
            "primary": "#325D88",
            "secondary": "#8e8c84",
            "success": "#93c54b",
            "info": "#29abe0",
            "warning": "#f47c3c",
            "danger": "#d9534f",
            "light": "#F8F5F0",
            "dark": "#3E3F3A",
            "bg": "#ffffff",
            "fg": "#3e3f3a",
            "selectbg": "#8e8c84",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#6E6D69",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_yeti": {
        "type": "light",
        "colors": {
            "primary": "#008cba",
            "secondary": "#707070",
            "success": "#43ac6a",
            "info": "#5bc0de",
            "warning": "#e99002",
            "danger": "#f04124",
            "light": "#EEEEEE",
            "dark": "#222222",
            "bg": "#ffffff",
            "fg": "#222222",
            "selectbg": "#707070",
            "selectfg": "#ffffff",
            "border": "#cccccc",
            "inputfg": "#222222",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_pulse": {
        "type": "light",
        "colors": {
            "primary": "#593196",
            "secondary": "#69676E",
            "success": "#13b955",
            "info": "#009cdc",
            "warning": "#efa31d",
            "danger": "#fc3939",
            "light": "#F9F8FC",
            "dark": "#17141F",
            "bg": "#ffffff",
            "fg": "#444444",
            "selectbg": "#69676e",
            "selectfg": "#ffffff",
            "border": "#cbc8d0",
            "inputfg": "#444444",
            "inputbg": "#fdfdfe",
            "active": "#e5e5e5",
        },
    },
    "pbs_united": {
        "type": "light",
        "colors": {
            "primary": "#e95420",
            "secondary": "#aea79f",
            "success": "#38b44a",
            "info": "#17a2b8",
            "warning": "#efb73e",
            "danger": "#df382c",
            "light": "#E9ECEF",
            "dark": "#772953",
            "bg": "#ffffff",
            "fg": "#333333",
            "selectbg": "#aea79f",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#333333",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_morph": {
        "type": "light",
        "colors": {
            "primary": "#378DFC",
            "secondary": "#aaaaaa",
            "success": "#43cc29",
            "info": "#5B62F4",
            "warning": "#FFC107",
            "danger": "#E52527",
            "light": "#F0F5FA",
            "dark": "#212529",
            "bg": "#D9E3F1",
            "fg": "#7B8AB8",
            "selectbg": "#aaaaaa",
            "selectfg": "#FBFDFF",
            "border": "#B9C7DA",
            "inputfg": "#7F8EBA",
            "inputbg": "#F0F5FA",
            "active": "#C3CCD8",
        },
    },
    "pbs_journal": {
        "type": "light",
        "colors": {
            "primary": "#eb6864",
            "secondary": "#aaaaaa",
            "success": "#22b24c",
            "info": "#336699",
            "warning": "#f5e625",
            "danger": "#f57a00",
            "light": "#F8F9FA",
            "dark": "#222222",
            "bg": "#ffffff",
            "fg": "#222222",
            "selectbg": "#aaaaaa",
            "selectfg": "#ffffff",
            "border": "#ced4da",
            "inputfg": "#565656",
            "inputbg": "#fff",
            "active": "#e5e5e5",
        },
    },
    "pbs_darkly": {
        "type": "dark",
        "colors": {
            "primary": "#375a7f",
            "secondary": "#444444",
            "success": "#00bc8c",
            "info": "#3498db",
            "warning": "#f39c12",
            "danger": "#e74c3c",
            "light": "#ADB5BD",
            "dark": "#303030",
            "bg": "#222222",
            "fg": "#ffffff",
            "selectbg": "#555555",
            "selectfg": "#ffffff",
            "border": "#222222",
            "inputfg": "#ffffff",
            "inputbg": "#2f2f2f",
            "active": "#1F1F1F",
        },
    },
    "pbs_superhero": {
        "type": "dark",
        "colors": {
            "primary": "#4c9be8",
            "secondary": "#4e5d6c",
            "success": "#5cb85c",
            "info": "#5bc0de",
            "warning": "#f0ad4e",
            "danger": "#d9534f",
            "light": "#ABB6C2",
            "dark": "#20374C",
            "bg": "#2b3e50",
            "fg": "#ffffff",
            "selectbg": "#526170",
            "selectfg": "#ffffff",
            "border": "#222222",
            "inputfg": "#ebebeb",
            "inputbg": "#32465a",
            "active": "#2B4155",
        },
    },
    "pbs_solar": {
        "type": "dark",
        "colors": {
            "primary": "#bc951a",
            "secondary": "#94a2a4",
            "success": "#44aca4",
            "info": "#3f98d7",
            "warning": "#d05e2f",
            "danger": "#d95092",
            "light": "#A9BDBD",
            "dark": "#073642",
            "bg": "#002B36",
            "fg": "#ffffff",
            "selectbg": "#0b5162",
            "selectfg": "#ffffff",
            "border": "#00252e",
            "inputfg": "#A9BDBD",
            "inputbg": "#073642",
            "active": "#002730",
        },
    },
    "pbs_cyborg": {
        "type": "dark",
        "colors": {
            "primary": "#2a9fd6",
            "secondary": "#555555",
            "success": "#77b300",
            "info": "#9933cc",
            "warning": "#ff8800",
            "danger": "#cc0000",
            "light": "#ADAFAE",
            "dark": "#222222",
            "bg": "#060606",
            "fg": "#ffffff",
            "selectbg": "#454545",
            "selectfg": "#ffffff",
            "border": "#060606",
            "inputfg": "#ffffff",
            "inputbg": "#191919",
            "active": "#282828",
        },
    },
    "pbs_vapor": {
        "type": "dark",
        "colors": {
            "primary": "#6e40c0",
            "secondary": "#ea38b8",
            "success": "#3af180",
            "info": "#1da2f2",
            "warning": "#ffbd05",
            "danger": "#e34b54",
            "light": "#44d7e8",
            "dark": "#170229",
            "bg": "#190831",
            "fg": "#32fbe2",
            "selectbg": "#461a8a",
            "selectfg": "#ffffff",
            "border": "#060606",
            "inputfg": "#bfb6cd",
            "inputbg": "#30115e",
            "active": "#17082E",
        },
    },
    "pbs_simplex": {
        "type": "light",
        "colors": {
            "primary": "#d8220e",
            "secondary": "#858e96",
            "success": "#469307",
            "info": "#0099ce",
            "warning": "#d88220",
            "danger": "#9a479e",
            "light": "#f2f2f2",
            "dark": "#3b3d3f",
            "bg": "#fcfcfc",
            "fg": "#3b3d3f",
            "selectbg": "#a9afb6",
            "selectfg": "#ffffff",
            "border": "#858e96",
            "inputfg": "#3b3d3f",
            "inputbg": "#fcfcfc",
            "active": "#e2e2e2",
        },
    },
    "pbs_cerculean": {
        "type": "light",
        "colors": {
            "primary": "#4bb1ea",
            "secondary": "#a9b4be",
            "success": "#84b251",
            "info": "#225384",
            "warning": "#e16e25",
            "danger": "#cf3c40",
            "light": "#eceef1",
            "dark": "#33383e",
            "bg": "#ffffff",
            "fg": "#2ea4e7",
            "selectbg": "#adb5bd",
            "selectfg": "#ffffff",
            "border": "#a9b4be",
            "inputfg": "#495057",
            "inputbg": "#ffffff",
            "active": "#e5e5e5",
        },
    },
    "pbs_tabler_dark": {
        "type": "dark",
        "colors": {
            "primary": "#066fd1",
            "secondary": "#6c7a91",
            "success": "#2fb344",
            "info": "#4299e1",
            "warning": "#f76707",
            "danger": "#d63939",
            "light": "#f6f8fb",
            "dark": "#151f2c",
            "bg": "#182433",
            "fg": "#f6f8fb",
            "selectbg": "#15304c",
            "selectfg": "#dce1e7",
            "border": "#066fd1",
            "inputfg": "#dce1e7",
            "inputbg": "#151f2c",
            "active": "#066fd1",
        },
    },
}
